ImbCoL-package: ImbCoL: Data Complexity Measures for Imbalanced...

Description Author(s)

Description

These are a set of measures to assess the difficulty of each class of a classification task based on the training set. The data must be structured in a data.frame format. For more information about the data complexity measures decomposed by class, check Barella et al. (doi: 10.1109/IJCNN.2018.8489661)

Author(s)

Maintainer: Victor Barella victorhb@icmc.usp.br


victorhb/ImbCoL documentation built on May 20, 2021, 12:18 p.m.