Description Usage Arguments Details Value References Examples
This function is responsable to extract the complexity measures from the classes of the classification tasks. For such, they take into account the overlap between classes imposed by feature values, the separability and distribution of the data points.
1 2 3 4 5 6 7 | complexity(...)
## Default S3 method:
complexity(x, y, groups = "all", ...)
## S3 method for class 'formula'
complexity(formula, data, groups = "all", ...)
|
... |
Not used. |
x |
A data.frame contained only the input attributes. |
y |
A response vector with one value for each row/component of x. |
groups |
A list of complexity measures groups or |
formula |
A formula to define the output column. |
data |
A data.frame dataset contained the input and output attributes. |
The following groups are allowed for this method:
The feature overlapping measures characterize how informative the available features are to separate the classes See overlapping for more details.
Neighborhood measures characterize the presence and density of same or different classes in local neighborhoods. See neighborhood for more details.
Linearity measures try to quantify whether the classes can be linearly separated. See linearity.class or linearity.regr for more details.
A numeric vector named by the requested complexity measures.
Victor H. Barella and Luis P. Garcia and Marcilio P. de Souto and Ana C. Lorena and Andre de Carvalho (2018). Data Complexity Measures for Imbalanced Classification Tasks. In 2018 International Joint Conference on Neural Networks (IJCNN) (pp. 1-8). IEEE.
Tin K Ho and Mitra Basu. (2002). Complexity measures of supervised classification problems. IEEE Transactions on Pattern Analysis and Machine Intelligence, 24, 3, 289–300.
Albert Orriols-Puig, Nuria Macia and Tin K Ho. (2010). Documentation for the data complexity library in C++. Technical Report. La Salle - Universitat Ramon Llull.
Ana C Lorena and Aron I Maciel and Pericles B C Miranda and Ivan G Costa and Ricardo B C Prudencio. (2018). Data complexity meta-features for regression problems. Machine Learning, 107, 1, 209–246.
1 2 3 | ## Extract all complexity measures for classification task
data(iris)
complexity(Species ~ ., iris)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.