Description Usage Arguments Details Value See Also Examples
Classification task. The linearity measures try to quantify if it is possible to separate the classes by a hyperplane. The underlying assumption is that a linearly separable problem can be considered simpler than a problem requiring a non-linear decision boundary.
1 2 3 4 5 6 7 | linearity.class(...)
## Default S3 method:
linearity.class(x, y, measures = "all", ...)
## S3 method for class 'formula'
linearity.class(formula, data, measures = "all", ...)
|
... |
Not used. |
x |
A data.frame contained only the input attributes. |
y |
A factor response vector with one label for each row/component of x. |
measures |
A list of measures names or |
formula |
A formula to define the class column. |
data |
A data.frame dataset contained the input attributes and class. |
The following measures are allowed for this method:
Sum of the error distance by linear programming (L1) computes the sum of the distances of incorrectly classified examples to a linear boundary used in their classification.
Error rate of linear classifier (L2) computes the error rate of the linear SVM classifier induced from dataset.
Non-linearity of a linear classifier (L3) creates a new dataset randomly interpolating pairs of training examples of the same class and then induce a linear SVM on the original data and measure the error rate in the new data points.
X in [1,2,3]. It is the decomposed version of the correponding LX function. Instead of giving a single complexity value for the dataset, it returns one complexity value per class.
A list named by the requested linearity measure.
Other complexity-measures: neighborhood,
overlapping
1 2 3 | ## Extract all linearity measures
data(iris)
linearity.class(Species ~ ., iris)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.